# Installation
> `npm install --save @types/c3`

# Summary
This package contains type definitions for C3js ( http://c3js.org/ ).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/c3

Additional Details
 * Last updated: Wed, 03 Apr 2019 18:23:30 GMT
 * Dependencies: @types/d3
 * Global values: c3

# Credits
These definitions were written by Marc Climent <https://github.com/mcliment>, Gerin Jacob <https://github.com/gerinjacob>, Bernd Hacker <https://github.com/denyo>, Dzmitry Shyndzin <https://github.com/dmitryshindin>, Tim Niemueller <https://github.com/timn>.
